# Citation

If you use PyZaplinePlus in your research, please cite:

```bibtex
@software{esmaeili2024pyzaplineplus,
  title = {PyZaplinePlus: Advanced Python library for automatic and adaptive removal of line noise from EEG data},
  author = {Esmaeili, Sina},
  year = {2024},
  url = {https://github.com/SinaEsmaeili/PyZaplinePlus}
}
```

And the original Zapline-plus paper:

```bibtex
@article{klug2022zapline,
  title={Zapline-plus: A Zapline extension for automatic and adaptive removal of frequency-specific noise artifacts in M/EEG},
  author={Klug, Marius and Kloosterman, Niels A},
  journal={Human Brain Mapping},
  year={2022},
  doi={10.1002/hbm.25832}
}
```

